==> spade_client-4.2.1.tar.gz: spade_client-4.2.1/spade_client/BundlesFunction.py <==
#
# Module: BundlesFunction
#
# Description: A class that class binds a set of bundles to a function execution call.
#

from __future__ import print_function

DEBUG_SEPARATOR = '--------'
HEADERS = {'Content-Type': 'application/xml',
           'Accept': 'application/xml'}

import sys
sys.path.append('.')

# This code is needed is pyxml if installed
pyxml=None
index = 0
for p in sys.path:
    if -1 != p.find('pyxml'):
         pyxml = p
    index += 1
if None != pyxml:
    sys.path.remove(pyxml)

import xml.etree.ElementTree as ET


def _eprint(*args, **kwargs):
    """Prints to standard error"""
    print(*args, file=sys.stderr, **kwargs)


from spade_client import Display, FatalError

def _check_status(url, r, expected):
    """Checks the return status of a request to a URL

    Keyword arguments:
    url      -- the URL to which the request was made
    r        -- the response to the request
    expected -- the expected response code
    """
    if expected == r.status_code:
        return
    elif 400 == r.status_code:
        raise FatalError('Application at "' + url  + '" can not process this request as it is bad', r.status_code, r.text)
    elif 401 == r.status_code:
        raise FatalError('Not authorized to execute commands for Application at "' + url, r.status_code, r.text)
    elif 404 == r.status_code:
        raise FatalError('Application at "' + url  + '" not found', r.status_code, r.text)
    raise FatalError('Unexpected status (' + str(r.status_code) + ') returned from "' + url  + '"', r.status_code, r.text)


class BundlesFunction:
    """
    This class binds a set of bundles to a function execution call.
    
    :param array bundles: the collection of bundles over which the function should be executed.
    """
    def __init__(self, bundles, session, xml = False):
        self.bundles = bundles
        self.debug = xml
        self.session = session


    def debug_separator(self):
        _eprint(DEBUG_SEPARATOR)


    def _pretty_print(self, url, s, response = True):
        """Prints out a formatted version of the supplied XML

        :param str url: the URL to which the request was made.
        :param str s: the XML to print.
        :param bool response: True is the XML is the reponse to a request.
        """
        if self.debug:
            if None != url:
                if response:
                    _eprint('URL : Response : ' + url)
                else:
                    _eprint('URL : Request :  ' + url)
            _eprint(xml.dom.minidom.parseString(s).toprettyxml())
            self.debug_separator()


    def _prepare_document():
        """
        Prepares a Bundles document contains the specified bundle identities
        """
        document = ET.Element('bundles')
        if None != self.bundles:
            for bundle in self.bundles:
                bundleElement = ET.Element('bundle')
                nameElement = ET.Element('name')
                nameElement.text = bundle
                bundleElement.append(nameElement)
                document.append(bundleElement)
        return document


    def report(self, action):
        document = _prepare_document()
        action_uri = bundle_action.find('uri').text
        self.__pretty_print(action_uri, ET.tostring(document), False)
        r = self.session.get(action_uri, data=ET.tostring(document), headers=HEADERS)
        _check_status(action_uri, r, 200)
        report = ET.fromstring(r.text)
        self.__pretty_print(action_uri, ET.tostring(report))
        Display.bundles_result(report, 'Results of ' + bundle_action.find('name').text)


    def command(self, action):
        document = _prepare_document()
        action_uri = bundle_action.find('uri').text
        self.__pretty_print(action_uri, ET.tostring(document), False)
        r = self.session.post(action_uri.find('uri').text, data=ET.tostring(document), headers=HEADERS)
        _check_status(action_uri, r, 202)
        report = ET.fromstring(r.text)
        self.__pretty_print(action_uri, ET.tostring(report))
        Display.bundles_result(report, 'Results of ' + bundle_action.find('name').text)

==> spade_client-4.5.0.dev33.tar.gz: spade_client-4.5.0.dev33/spade_client/BundlesFunction.py <==
#
# Module: BundlesFunction
#
# Description: A class that class binds a set of bundles to a function execution call.
#

from __future__ import print_function

import sys

# This code is needed is pyxml if installed
pyxml=None
index = 0
for p in sys.path:
    if -1 != p.find('pyxml'):
         pyxml = p
    index += 1
if None != pyxml:
    sys.path.remove(pyxml)

import xml.etree.ElementTree as ET

BUNDLES_XML = "application/gov.lbl.nest.spade.rs.Bundles+xml"

from spade_client import Display, ItemsFunction, FatalError

class BundlesFunction(ItemsFunction):
    """
    This class binds a set of bundles to a function execution call.
    
    :param array bundles: the collection of bundles over which the function should be executed.
    """
    def __init__(self, bundles, session, xml = False):
        self.bundles = bundles
        ItemsFunction.__init__(self, session, xml)


    def _display_report(self,
                        action,
                        report):
        section = action.find('name').text.title()
        if "digests" == report.tag:
            Display.digests_result(report,
                                   section)
        else:
            bundles_result(report,
                           section)


    def _prepare_document(self, media_type):
        """
        Prepares a Bundles document contains the specified bundle identities
        """
        if BUNDLES_XML != media_type:
            raise FatalError('Can not handle "' + media_type + '" requested for this action"', -5, None)
        document = ET.Element('bundles')
        if None != self.bundles:
            for bundle in self.bundles:
                bundleElement = ET.Element('bundle')
                nameElement = ET.Element('name')
                nameElement.text = bundle
                bundleElement.append(nameElement)
                document.append(bundleElement)
        return document
